@@ -49,15 +49,18 @@ got6 <- GWAS(oi,
      file.path(tdir, "out.log"), SNP=c(3:5))
 expect_true(is.null(got6$data$observedStats$means))
 
-pgen <- loadResults(file.path(tdir, "out.log"), "snp2i3")
+pgen <- loadResults(file.path(tdir, "out.log"), "snp_to_i3")
 rx <- which(min(pgen$P) == pgen$P)
 expect_equal(rx, 3)
 expect_equal(pgen$P[rx], .155, tolerance=1e-2)
 
-expect_error(GWAS(oi,
-                  file.path(dir,"example.pgen"),
-                  file.path(tdir, "out.log"), SNP=c(250)),
-             "out of data")
+test_that("out of data", {
+  skip_on_os('mac') # exceptions are broken
+  expect_error(GWAS(oi,
+                    file.path(dir,"example.pgen"),
+                    file.path(tdir, "out.log"), SNP=c(250)),
+               "out of data")
+})
 
 oi <- expect_warning(buildItem(pheno, paste0("i", 3), fitfun = "ML",
                    minMAF=.1),
@@ -68,7 +71,7 @@ GWAS(oi,
      file.path(dir,"example.pgen"),
      file.path(tdir, "out.log"), SNP=c(3:5))
 
-ml <- loadResults(file.path(tdir, "out.log"), "snp2i3")
+ml <- loadResults(file.path(tdir, "out.log"), "snp_to_i3")
 expect_equal(cor(ml$P, pgen$P), 1, tolerance=1e-3)
 
 expect_error(buildItem(pheno, paste0("i", 1), fitfun = "bob"),
@@ -83,12 +86,12 @@ GWAS(oi,
      file.path(dir,"example.pgen"),
      file.path(tdir, "out.log"), SNP=c(11:20))
 
-pgen <- loadResults(file.path(tdir, "out.log"), "snp2i2")
+pgen <- loadResults(file.path(tdir, "out.log"), "snp_to_i2")
 rx <- which(min(pgen$P) == pgen$P)
 expect_equal(rx, 10)
 expect_equal(pgen$P[rx], .0251, tolerance=1e-2)
 
-pgen <- loadResults(file.path(tdir, "out.log"), "snp2i3")
+pgen <- loadResults(file.path(tdir, "out.log"), "snp_to_i3")
 rx <- which(min(pgen$P) == pgen$P)
 expect_equal(rx, 4)
 expect_equal(pgen$P[rx], .086, tolerance=1e-2)
@@ -103,12 +106,12 @@ z1 = GWAS(buildOneFac(pheno, paste0("i", 1:numIndicators)),
      file.path(dir,"example.pgen"),
      file.path(tdir, "out.log"), SNP=c(3:5))
 
-pgen <- loadResults(file.path(tdir, "out.log"), "snp2F")
-pgen2 <- loadResults(rep(file.path(tdir, "out.log"), 2), 'snp2F')
+pgen <- loadResults(file.path(tdir, "out.log"), "snp_to_F", signAdj='lambda_i1')
+pgen2 <- loadResults(rep(file.path(tdir, "out.log"), 2), 'snp_to_F', signAdj='lambda_i1')
 
 expect_equal(pgen$SNP, paste0("RSID_", 4:6))
 expect_equal(pgen2$SNP, rep(paste0("RSID_", 4:6), 2))
-expect_equal(pgen$snp2F, c(.188, .066, -.081), tolerance=.001)
+expect_equal(pgen$snp_to_F, c(.188, .066, -.081), tolerance=.001)
 
 pgen <- read.table(file.path(tdir, "out.log"), stringsAsFactors = FALSE, header=TRUE,
                    sep="\t", check.names=FALSE, quote="", comment.char="")
@@ -140,7 +143,7 @@ expect_equivalent(pgen$i2_Thr_1, rep(0,3), tolerance=0.15)
 l2 <- pgen[,paste0('lambda_i',1:7)]
 expect_equivalent(colMeans(l2) / loadings, rep(1, numIndicators), tolerance=.2)
 
-pgen <- loadResults(file.path(tdir, "out.log"), "snp2i2")
+pgen <- loadResults(file.path(tdir, "out.log"), "snp_to_i2")
 expect_equal(pgen$P, c(0.481, 0.896, 0.412), tolerance=1e-2)
 
 # -----------------
